defmodule Slax.MixProject do
  use Mix.Project

  def project do
    [
      app: :slax,
      version: "0.1.0",
      elixir: "~> 1.14",
      elixirc_paths: elixirc_paths(Mix.env()),
      start_permanent: Mix.env() == :prod,
      aliases: aliases(),
      deps: deps()
    ]
  end

  def application do
    [
      mod: {Slax.Application, []},
      extra_applications: [:logger, :runtime_tools]
    ]
  end

  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(_), do: ["lib"]

  defp deps do
    [
      {:bcrypt_elixir, "~> 3.0"},
      {:bandit, "~> 1.5"},
      {:dns_cluster, "~> 0.1.1"},
      {:ecto_sql, "~> 3.10"},
      {:esbuild, "~> 0.8.0", runtime: Mix.env() == :dev},
      {:finch, "~> 0.19.0"},
      {:floki, ">= 0.30.0", only: :test},
      {:gettext, "~> 0.26.0"},
      {:heroicons,
       github: "tailwindlabs/heroicons",
       tag: "v2.1.1",
       sparse: "optimized",
       app: false,
       compile: false,
       depth: 1},
      {:jason, "~> 1.4.0"},
      {:phoenix, "~> 1.7.0"},
      {:phoenix_ecto, "~> 4.6.0"},
      {:phoenix_html, "~> 4.2.0"},
      {:phoenix_live_reload, "~> 1.5.0", only: :dev},
      {:phoenix_live_view, "~> 1.0.0", override: true},
      {:phoenix_live_dashboard, "~> 0.8.3"},
      {:postgrex, ">= 0.0.0"},
      {:swoosh, "~> 1.17.0"},
      {:tailwind, "~> 0.2.0", runtime: Mix.env() == :dev},
      {:testcontainers, "~> 1.11.0", only: [:dev, :test]},
      {:telemetry_metrics, "~> 1.1.0"},
      {:telemetry_poller, "~> 1.1.0"},
      {:timex, "~> 3.7.0"}
    ]
  end

  # See the documentation for `Mix` for more info on aliases.
  defp aliases do
    [
      setup: ["deps.get", "assets.setup", "assets.build"],
      "assets.setup": ["tailwind.install --if-missing", "esbuild.install --if-missing"],
      "assets.build": ["tailwind slax", "esbuild slax"],
      "assets.deploy": [
        "tailwind slax --minify",
        "esbuild slax --minify",
        "phx.digest"
      ]
    ]
  end
end
